go_get_ip

package module
v0.0.0-...-6b920b7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 24, 2018 License: MIT Imports: 2 Imported by: 0

README

go-get-ip

A simple library to get the current ipv4 or ipv6 address using ident.me This project does not use any external libraries and all requests are made over https.

Usage:

To download this library just run:

go get github.com/modmuss50/go-get-ip

The api is extremely easy to use, see the example below:

package main

import (
"fmt"
"github.com/modmuss50/go-get-ip"
)

func  main() {
    ip, err  := go_get_ip.GetIPV4()
    if err !=  nil {
        //Failed to get the ip address, this may happen if you do not have internet access
        panic(err)
    } else {
        fmt.Println("IPv4: "  + ip)
    }
    
    ipv6, err  := go_get_ip.GetIPV6()
    if err !=  nil {
        //Failed to get the ip address, this may happen if you do not have internet access
        //This will only work if the network is properly configured to work with ipv6
        panic(err)
    } else {
        fmt.Println("IPv6: "  + ipv6)
    }
}
Things to note:

GetIPV6 will only work when the network is configured to work with ipv6, so don't forget to gracefully handle the errors.

If you need help feel free to ask questions on our discord server.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetIPV4

func GetIPV4() (string, error)

GetIPV4 returns the IP version 4 address string format

func GetIPV6

func GetIPV6() (string, error)

GetIPV6 returns the IP version 6 address in a string format

Types

This section is empty.

Jump to